Class HalClient

java.lang.Object
org.refcodes.hal.HalClient
All Implemented Interfaces:
org.refcodes.web.OauthTokenAccessor, org.refcodes.web.OauthTokenAccessor.OauthTokenBuilder<HalClient>, org.refcodes.web.OauthTokenAccessor.OauthTokenMutator, org.refcodes.web.OauthTokenAccessor.OauthTokenProperty

public class HalClient extends Object implements org.refcodes.web.OauthTokenAccessor.OauthTokenProperty, org.refcodes.web.OauthTokenAccessor.OauthTokenBuilder<HalClient>
The HalClient lets you comfortably introspect and manage (in terms of CRUD) HAL resources. You may use it reflect the data structures of entities accessible by remote HAL endpoints as well as apply CRUD operations on the introspected entities. This means that you interact completely dynamically with the HAL resource at runtime instead of having to provide static data structures at compile time. Still you may go wit static data types as we use the CanonicalMap (as well as the CanonicalMap.CanonicalMapBuilder) to operate upon the dynamic data structures. Implementations may use the RestfulHttpServer and it's implementations such as the HttpRestServer. See also "https://en.wikipedia.org/wiki/Hypertext_Application_Language".