java.lang.Object
org.refcodes.struct.PathMapBuilderImpl<String>
org.refcodes.struct.CanonicalMapBuilderImpl
org.refcodes.hal.HalDataImpl
- All Implemented Interfaces:
Serializable,Map<String,,String> HalData,HalMap,org.refcodes.mixin.AnnotatorAccessor,org.refcodes.mixin.Clearable,org.refcodes.mixin.DelimiterAccessor,org.refcodes.mixin.Dumpable,org.refcodes.mixin.EmptyAccessor,org.refcodes.mixin.TypeAccessor<String>,org.refcodes.struct.CanonicalMap,org.refcodes.struct.CanonicalMap.CanonicalMapBuilder,org.refcodes.struct.CanonicalMap.MutableCanonicalMap,org.refcodes.struct.Containable,org.refcodes.struct.Dictionary<String,,String> org.refcodes.struct.Dictionary.MutableDictionary<String,,String> org.refcodes.struct.Dictionary.MutableDictionary.DictionaryBuilder<String,,String, org.refcodes.struct.PathMap.PathMapBuilder<String>> org.refcodes.struct.InterOperableMap<String>,org.refcodes.struct.InterOperableMap.InterOperableMapBuilder<String>,org.refcodes.struct.InterOperableMap.MutableInterOperableMap<String>,org.refcodes.struct.Keys<String,,String> org.refcodes.struct.Keys.MutableKeys<String,,String> org.refcodes.struct.Keys.MutableValues<String,,String> org.refcodes.struct.PathMap<String>,org.refcodes.struct.PathMap.MutablePathMap<String>,org.refcodes.struct.PathMap.PathMapBuilder<String>
The
HalDataImpl implements the HalData interface by extending
the CanonicalMapBuilderImpl class. The path delimiter as of
PathMapBuilderImpl.getDelimiter() is set to be the Delimiter.PATH character.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AnnotatorAccessor
org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B extends org.refcodes.mixin.AnnotatorAccessor.AnnotatorBuilder<B>>, org.refcodes.mixin.AnnotatorAccessor.AnnotatorMutator, org.refcodes.mixin.AnnotatorAccessor.AnnotatorPropertyNested classes/interfaces inherited from interface org.refcodes.struct.CanonicalMap
org.refcodes.struct.CanonicalMap.CanonicalMapBuilder, org.refcodes.struct.CanonicalMap.MutableCanonicalMapNested classes/interfaces inherited from interface org.refcodes.mixin.DelimiterAccessor
org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B extends org.refcodes.mixin.DelimiterAccessor.DelimiterBuilder<B>>, org.refcodes.mixin.DelimiterAccessor.DelimiterMutator, org.refcodes.mixin.DelimiterAccessor.DelimiterPropertyNested classes/interfaces inherited from interface org.refcodes.struct.Dictionary
org.refcodes.struct.Dictionary.MutableDictionary<K extends Object,V extends Object> Nested classes/interfaces inherited from interface org.refcodes.struct.Dictionary.MutableDictionary
org.refcodes.struct.Dictionary.MutableDictionary.DictionaryBuilder<K extends Object,V extends Object, B extends org.refcodes.struct.Dictionary.MutableDictionary.DictionaryBuilder<K, V, B>> Nested classes/interfaces inherited from interface org.refcodes.mixin.EmptyAccessor
org.refcodes.mixin.EmptyAccessor.EmptyMutator, org.refcodes.mixin.EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface org.refcodes.struct.InterOperableMap
org.refcodes.struct.InterOperableMap.InterOperableMapBuilder<T extends Object>, org.refcodes.struct.InterOperableMap.MutableInterOperableMap<T extends Object>Nested classes/interfaces inherited from interface org.refcodes.struct.Keys
org.refcodes.struct.Keys.MutableKeys<K extends Object,V extends Object>, org.refcodes.struct.Keys.MutableValues<K extends Object, V extends Object> Nested classes/interfaces inherited from interface java.util.Map
Map.Entry<K extends Object,V extends Object> Nested classes/interfaces inherited from interface org.refcodes.struct.PathMap
org.refcodes.struct.PathMap.MutablePathMap<T extends Object>, org.refcodes.struct.PathMap.PathMapBuilder<T extends Object>Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object> -
Field Summary
Fields inherited from class org.refcodes.struct.PathMapBuilderImpl
_backingMapFields inherited from interface org.refcodes.hal.HalMap
HAL_ALPS, HAL_DESCRIPTOR, HAL_DESCRIPTORS, HAL_DOC, HAL_EMBEDDED, HAL_ENUM, HAL_FORMAT, HAL_HREF, HAL_LINKS, HAL_NAME, HAL_PATH_SELF_HREF, HAL_PROFILE, HAL_PROPERTIES, HAL_READ_ONLY, HAL_REF, HAL_RELATION, HAL_SELF, HAL_TEMPLATED, HAL_TITLE, HAL_TYPE, HAL_VALUE, META_DATA_ARRAY, META_DATA_ENUM, META_DATA_FORMAT, META_DATA_HREF, META_DATA_READ_ONLY, META_DATA_SELF, META_DATA_TYPE, META_DATA_VALUE, ROOT_PATHFields inherited from interface org.refcodes.struct.PathMap
ANNOTATOR, DELIMITER -
Constructor Summary
ConstructorsConstructorDescriptionCreate an emptyHalDatainstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations.HalDataImpl(Object aObj) Create aHalDatainstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.HalDataImpl(Object aObj, String aFromPath) Creates aHalDatainstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.HalDataImpl(String aToPath, Object aObj) Create aHalDatainstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.HalDataImpl(String aToPath, Object aObj, String aFromPath) Creates aHalDatainstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATHfor the path declarations. -
Method Summary
Modifier and TypeMethodDescriptionretrieveBetween(String aFromPath, String aToPath) retrieveFrom(String aFromPath) retrieveTo(String aToPath) Methods inherited from class org.refcodes.struct.CanonicalMapBuilderImpl
fromInstance, fromObject, toInstanceMethods inherited from class org.refcodes.struct.PathMapBuilderImpl
clear, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, createBackingMap, entrySet, equals, forEach, fromValue, fromValue, get, getAnnotator, getDelimiter, getOrDefault, getType, hashCode, insert, insertBetween, insertFrom, insertTo, isEmpty, keySet, merge, merge, mergeBetween, mergeFrom, mergeTo, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, toDataStructure, toString, toType, valuesMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.AnnotatorAccessor
getAnnotatorMethods inherited from interface org.refcodes.struct.CanonicalMap
asArray, asArray, asArray, asArray, asBooleanArray, asBooleanArray, asBooleanArray, asBooleanArray, asByteArray, asByteArray, asByteArray, asByteArray, asCharArray, asCharArray, asCharArray, asCharArray, asDoubleArray, asDoubleArray, asDoubleArray, asDoubleArray, asFloatArray, asFloatArray, asFloatArray, asFloatArray, asIntArray, asIntArray, asIntArray, asIntArray, asLongArray, asLongArray, asLongArray, asLongArray, asShortArray, asShortArray, asShortArray, asShortArray, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirs, getDirs, getDirs, getDirs, getDirs, toMap, toPropertiesMethods inherited from interface org.refcodes.struct.CanonicalMap.MutableCanonicalMap
containsValue, insert, insertBetween, insertFrom, insertTo, put, put, put, put, put, putAll, putAll, putAll, removeFrom, toDumpMethods inherited from interface org.refcodes.mixin.Clearable
clearMethods inherited from interface org.refcodes.struct.Containable
sizeMethods inherited from interface org.refcodes.mixin.DelimiterAccessor
getDelimiterMethods inherited from interface org.refcodes.mixin.Dumpable
toDump, toPrintableMethods inherited from interface org.refcodes.mixin.EmptyAccessor
isEmptyMethods inherited from interface org.refcodes.hal.HalData
exportHref, exportHref, exportHref, exportHref, exportHref, exportHref, exportHref, exportHref, exportHref, exportHref, exportHref, exportHref, exportHref, exportHref, exportHref, exportHref, exportHref, exportHref, exportHref, exportHref, getDirAt, getDirAt, getId, getSelfHref, importHref, importHref, importHref, importHref, importHref, importHref, importHref, importHref, importHref, importHref, importHref, importHref, importHref, importHref, importHref, importHref, importHref, importHref, importHref, importHref, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, putDirAt, query, query, query, query, query, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryBetween, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryFrom, queryTo, queryTo, queryTo, queryTo, queryTo, queryTo, removeAll, removeAll, removeAll, removeAll, removeAll, removeAll, removeDirAt, removeDirAt, removeDirAt, removeDirAt, removeDirAt, removeFrom, removeFrom, removeFrom, removeFrom, removePaths, removePaths, retrieveBetween, retrieveBetween, retrieveBetween, retrieveBetween, retrieveFrom, retrieveFrom, retrieveFrom, retrieveFrom, retrieveTo, retrieveTo, retrieveTo, retrieveTo, withInsert, withInsert, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertBetween, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertFrom, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withInsertTo, withMerge, withMerge, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeBetween, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeFrom, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withMergeTo, withPut, withPut, withPut, withPut, withPut, withPutBoolean, withPutBoolean, withPutBoolean, withPutBoolean, withPutBoolean, withPutByte, withPutByte, withPutByte, withPutByte, withPutByte, withPutChar, withPutChar, withPutChar, withPutChar, withPutChar, withPutClass, withPutClass, withPutClass, withPutClass, withPutClass, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDirAt, withPutDouble, withPutDouble, withPutDouble, withPutDouble, withPutDouble, withPutEnum, withPutEnum, withPutEnum, withPutEnum, withPutEnum, withPutFloat, withPutFloat, withPutFloat, withPutFloat, withPutFloat, withPutInt, withPutInt, withPutInt, withPutInt, withPutInt, withPutLong, withPutLong, withPutLong, withPutLong, withPutLong, withPutShort, withPutShort, withPutShort, withPutShort, withPutShort, withPutString, withPutString, withPutString, withPutString, withPutString, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemoveFrom, withRemovePathsMethods inherited from interface org.refcodes.struct.InterOperableMap
getBoolean, getBoolean, getBoolean, getBoolean, getBoolean, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getByte, getByte, getByte, getByte, getByte, getByteOr, getByteOr, getByteOr, getByteOr, getByteOr, getChar, getChar, getChar, getChar, getChar, getCharOr, getCharOr, getCharOr, getCharOr, getCharOr, getClass, getClass, getClass, getClass, getClass, getClassOr, getClassOr, getClassOr, getClassOr, getClassOr, getDouble, getDouble, getDouble, getDouble, getDouble, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getEnum, getEnum, getEnum, getEnum, getEnum, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getFloat, getFloat, getFloat, getFloat, getFloat, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getInt, getInt, getInt, getInt, getInt, getIntOr, getIntOr, getIntOr, getIntOr, getIntOr, getLong, getLong, getLong, getLong, getLong, getLongOr, getLongOr, getLongOr, getLongOr, getLongOr, getShort, getShort, getShort, getShort, getShort, getShortOr, getShortOr, getShortOr, getShortOr, getShortOr, getString, getString, getString, getString, getString, getStringOr, getStringOr, getStringOr, getStringOr, getStringOrMethods inherited from interface org.refcodes.struct.InterOperableMap.MutableInterOperableMap
containsValue, insert, insertBetween, insertFrom, insertTo, putBoolean, putBoolean, putBoolean, putBoolean, putBoolean, putByte, putByte, putByte, putByte, putByte, putChar, putChar, putChar, putChar, putChar, putClass, putClass, putClass, putClass, putClass, putDouble, putDouble, putDouble, putDouble, putDouble, putEnum, putEnum, putEnum, putEnum, putEnum, putFloat, putFloat, putFloat, putFloat, putFloat, putInt, putInt, putInt, putInt, putInt, putLong, putLong, putLong, putLong, putLong, putShort, putShort, putShort, putShort, putShort, putString, putString, putString, putString, putStringMethods inherited from interface org.refcodes.struct.Keys
containsKey, get, getOr, keySet, use, valuesMethods inherited from interface org.refcodes.struct.Keys.MutableValues
putMethods inherited from interface java.util.Map
clear, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, entrySet, equals, forEach, get, getOrDefault, hashCode, isEmpty, keySet, merge, put, putIfAbsent, remove, remove, replace, replace, replaceAll, size, valuesMethods inherited from interface org.refcodes.struct.PathMap
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPropertyPath, toType, toType, toType, toType, toType, toTypeMethods inherited from interface org.refcodes.struct.PathMap.MutablePathMap
add, add, add, add, add, add, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, delete, delete, delete, delete, delete, fromType, fromType, fromType, fromType, fromType, fromType, fromType, fromType, insert, insert, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, merge, merge, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, put, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, remove, remove, remove, removeValueAt, removeValueAt, removeValueAt, removeValueAt, removeValueAt, toSourceCode, toSourceCodeMethods inherited from interface org.refcodes.mixin.TypeAccessor
getType
-
Constructor Details
-
HalDataImpl
public HalDataImpl()Create an emptyHalDatainstance using the default path delimiter "/" (Delimiter.PATH) for the path declarations. -
HalDataImpl
Creates aHalDatainstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.
-
HalDataImpl
Create aHalDatainstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aObj- The object from which the elements are to be added.
-
HalDataImpl
Creates aHalDatainstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATHfor the path declarations.- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.
-
HalDataImpl
Create aHalDatainstance containing the elements as ofPathMap.MutablePathMap.insert(Object)using the default path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.
-
-
Method Details
-
retrieveFrom
- Specified by:
retrieveFromin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveFromin interfaceHalData- Specified by:
retrieveFromin interfaceHalMap- Specified by:
retrieveFromin interfaceorg.refcodes.struct.PathMap<String>- Overrides:
retrieveFromin classorg.refcodes.struct.CanonicalMapBuilderImpl
-
retrieveTo
- Specified by:
retrieveToin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveToin interfaceHalData- Specified by:
retrieveToin interfaceHalMap- Specified by:
retrieveToin interfaceorg.refcodes.struct.PathMap<String>- Overrides:
retrieveToin classorg.refcodes.struct.CanonicalMapBuilderImpl
-
retrieveBetween
- Specified by:
retrieveBetweenin interfaceorg.refcodes.struct.CanonicalMap- Specified by:
retrieveBetweenin interfaceHalData- Specified by:
retrieveBetweenin interfaceHalMap- Specified by:
retrieveBetweenin interfaceorg.refcodes.struct.PathMap<String>
-
withPut
- Specified by:
withPutin interfaceorg.refcodes.struct.Dictionary.MutableDictionary.DictionaryBuilder<String,String, org.refcodes.struct.PathMap.PathMapBuilder<String>> - Specified by:
withPutin interfaceHalData- Specified by:
withPutin interfaceHalMap- Specified by:
withPutin interfaceorg.refcodes.struct.InterOperableMap.InterOperableMapBuilder<String>- Overrides:
withPutin classorg.refcodes.struct.CanonicalMapBuilderImpl
-