Class HalDataPageImpl

All Implemented Interfaces:
Serializable, Cloneable, Iterable<HalData>, Collection<HalData>, List<HalData>, RandomAccess, HalDataPage

public class HalDataPageImpl extends ArrayList<HalData> implements HalDataPage
Implementation of the HalDataPage interface.
See Also:
  • Constructor Details

    • HalDataPageImpl

      protected HalDataPageImpl()
      Default constructor for usage by sub-classes.
    • HalDataPageImpl

      public HalDataPageImpl(int aPageNumber, int aPageSize, int aPageCount)
      Constructs the HalDataPage instances with the given pagination metrics.
      Parameters:
      aPageNumber - The page's number as of pagination.
      aPageSize - The page's size as of pagination.
      aPageCount - The total page count of the overall result set.
  • Method Details

    • getPageNumber

      public int getPageNumber()
      Returns the number of the page which this HalDataPage instances represents.
      Specified by:
      getPageNumber in interface HalDataPage
      Returns:
      The HalDataPage result set's page number as of pagination.
    • getPageSize

      public int getPageSize()
      Returns the maximum size of the page being requested for the HalDataPage result set. Returns -1 in case no page size has been specified.
      Specified by:
      getPageSize in interface HalDataPage
      Returns:
      The HalDataPage result set's page size as of pagination.
    • getPageCount

      public int getPageCount()
      Returns the total number of the pages which are available for retrieval.
      Specified by:
      getPageCount in interface HalDataPage
      Returns:
      The total number of the pages repesenting the overall result set..