Uses of Class
org.refcodes.hal.HalClient
-
Uses of HalClient in org.refcodes.hal
Classes in org.refcodes.hal that implement interfaces with type arguments of type HalClientModifier and TypeClassDescriptionclassTheHalClientlets you comfortably introspect and manage (in terms of CRUD) HAL resources.Methods in org.refcodes.hal that return HalClientModifier and TypeMethodDescriptionHalClient.withExcludeEntities(String[] entities) Sets the names of the entities to be excluded by theHalClient.HalClient.withIncludeEntities(String[] entities) Sets the names of the entities to be included by theHalClient.HalClient.withOAuthToken(OauthToken aOauthToken)