Uses of Class
org.refcodes.hal.HalData
-
Uses of HalData in org.refcodes.hal
Subclasses with type arguments of type HalData in org.refcodes.halModifier and TypeClassDescriptionclassIn case the a paginated result set is expected when querying theHalClient, then aHalDataPagewill be returned containing the theHalDatainstances correlating to the requested page as well as additional information about the number of total pages available.Methods in org.refcodes.hal that return HalDataModifier and TypeMethodDescriptionCreates a new entitie's element (row) at the HAL resource consisting of the properties as of the providedImmutableCanonicalTable.Creates a new entitie's element (row) at the HAL resource consisting of the properties as of the providedImmutableCanonicalTable.HalData.exportHref(Object aPath) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(Object... aPathElements) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(Object[] aPathElements, FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(Object aPath, FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(String aPath) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(String... aPathElements) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(String[] aPathElements, FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(String aPath, FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(Collection<?> aPathElements) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(Collection<?> aPathElements, FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, Object aPath) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, Object... aPathElements) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, Object[] aPathElements, FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, Object aPath, FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, String aPath) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, String... aPathElements) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, String[] aPathElements, FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, String aPath, FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, Collection<?> aPathElements) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, Collection<?> aPathElements, FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.getDirAt(int aIndex) HalData.putDirAt(int aIndex, ImmutablePathTable<String> aDir) HalData.putDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) HalData.putDirAt(Object aPath, int aIndex, ImmutablePathTable<String> aDir) HalData.putDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) HalData.putDirAt(String aPath, int aIndex, ImmutablePathTable<String> aDir) HalData.putDirAt(Collection<?> aPathElements, int aIndex, Object aDir) HalData.putDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<String> aDir) HalData.query(Collection<?> aQueryElements) HalData.queryBetween(Object[] aFromPath, Object[] aPathQuery, Object[] aToPath) HalData.queryBetween(Object aFromPath, Object aPathQuery, Object aToPath) HalData.queryBetween(String[] aFromPath, String[] aPathQuery, String[] aToPath) HalData.queryBetween(String aFromPath, String aPathQuery, String aToPath) HalData.queryBetween(String aFromPath, Pattern aRegExp, String aToPath) HalData.queryBetween(Collection<?> aFromPath, Collection<?> aPathQuery, Collection<?> aToPath) HalData.queryFrom(Collection<?> aPathQuery, Collection<?> aFromPath) HalData.queryTo(Collection<?> aPathQuery, String aToPath) Retrieves the properties with the according values for the given entity with the given TID from the HAL resource.HalClient.read(String aEntity, Long aId, TraversalMode aMode) Retrieves the properties with the according values for the given entity with the given TID from the HAL resource.HalClient.read(String aEntity, Long aId, TraversalMode aMode, FormFields aQueryFields) Retrieves the properties with the according values for the given entity with the given TID from the HAL resource.HalClient.read(String aEntity, Long aId, FormFields aQueryFields) Retrieves the properties with the according values for the given entity with the given TID from the HAL resource.HalData.removeAll(Collection<?> aPathQueryElements) HalData.removeDirAt(int aIndex) HalData.removeDirAt(Object[] aPathElements, int aIndex) HalData.removeDirAt(Object aPath, int aIndex) HalData.removeDirAt(String[] aPathElements, int aIndex) HalData.removeDirAt(String aPath, int aIndex) HalData.removeFrom(Object aPath) HalData.removeFrom(Object... aPathElements) HalData.removeFrom(String aPath) HalData.removeFrom(String... aPathElements) HalData.removePaths(String... aPaths) HalData.removePaths(Collection<?> aPaths) HalData.retrieveBetween(Object[] aFromPath, Object[] aToPath) HalData.retrieveBetween(Object aFromPath, Object aToPath) HalData.retrieveBetween(String[] aFromPath, String[] aToPath) HalData.retrieveBetween(String aFromPath, String aToPath) HalData.retrieveBetween(Collection<?> aFromPath, Collection<?> aToPath) HalData.retrieveFrom(Object aParentPath) HalData.retrieveFrom(Object... aPathElements) HalData.retrieveFrom(String aFromPath) HalData.retrieveFrom(String... aPathElements) HalData.retrieveFrom(Collection<?> aPathElements) HalData.retrieveTo(Object aToPath) HalData.retrieveTo(Object... aToPathElements) HalData.retrieveTo(String aToPath) HalData.retrieveTo(String... aToPathElements) HalData.retrieveTo(Collection<?> aToPathElements) Creates a new entitie's element (row) at the HAL resource consisting of the properties as of the providedImmutableCanonicalTable.Updates an existing entitie's element (row) at the HAL resource using the properties as of the providedImmutableCanonicalTable.HalData.withInsert(Object aObj) HalData.withInsert(ImmutablePathTable<String> aFrom) HalData.withInsertBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) HalData.withInsertBetween(Object[] aToPathElements, ImmutablePathTable<String> aFrom, Object[] aFromPathElements) HalData.withInsertBetween(Object aToPath, Object aFrom, Object aFromPath) HalData.withInsertBetween(Object aToPath, ImmutablePathTable<String> aFrom, Object aFromPath) HalData.withInsertBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) HalData.withInsertBetween(String[] aToPathElements, ImmutablePathTable<String> aFrom, String[] aFromPathElements) HalData.withInsertBetween(String aToPath, Object aFrom, String aFromPath) HalData.withInsertBetween(String aToPath, ImmutablePathTable<String> aFrom, String aFromPath) HalData.withInsertBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) HalData.withInsertBetween(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) HalData.withInsertFrom(Object aFrom, Object aFromPath) HalData.withInsertFrom(Object aFrom, Object... aFromPathElements) HalData.withInsertFrom(Object aFrom, String aFromPath) HalData.withInsertFrom(Object aFrom, String... aFromPathElements) HalData.withInsertFrom(Object aFrom, Collection<?> aFromPathElements) HalData.withInsertFrom(ImmutablePathTable<String> aFrom, Object aFromPath) HalData.withInsertFrom(ImmutablePathTable<String> aFrom, Object... aFromPathElements) HalData.withInsertFrom(ImmutablePathTable<String> aFrom, String aFromPath) HalData.withInsertFrom(ImmutablePathTable<String> aFrom, String... aFromPathElements) HalData.withInsertFrom(ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) HalData.withInsertTo(Object[] aToPathElements, Object aFrom) HalData.withInsertTo(Object[] aToPathElements, ImmutablePathTable<String> aFrom) HalData.withInsertTo(Object aToPath, Object aFrom) HalData.withInsertTo(Object aToPath, ImmutablePathTable<String> aFrom) HalData.withInsertTo(String[] aToPathElements, Object aFrom) HalData.withInsertTo(String[] aToPathElements, ImmutablePathTable<String> aFrom) HalData.withInsertTo(String aToPath, Object aFrom) HalData.withInsertTo(String aToPath, ImmutablePathTable<String> aFrom) HalData.withInsertTo(Collection<?> aToPathElements, Object aFrom) HalData.withInsertTo(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom) HalData.withMerge(ImmutablePathTable<String> aFrom) HalData.withMergeBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) HalData.withMergeBetween(Object[] aToPathElements, ImmutablePathTable<String> aFrom, Object[] aFromPathElements) HalData.withMergeBetween(Object aToPath, Object aFrom, Object aFromPath) HalData.withMergeBetween(Object aToPath, ImmutablePathTable<String> aFrom, Object aFromPath) HalData.withMergeBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) HalData.withMergeBetween(String[] aToPathElements, ImmutablePathTable<String> aFrom, String[] aFromPathElements) HalData.withMergeBetween(String aToPath, Object aFrom, String aFromPath) HalData.withMergeBetween(String aToPath, ImmutablePathTable<String> aFrom, String aFromPath) HalData.withMergeBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) HalData.withMergeBetween(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) HalData.withMergeFrom(Object aFrom, Object aFromPath) HalData.withMergeFrom(Object aFrom, Object... aFromPathElements) HalData.withMergeFrom(Object aFrom, String aFromPath) HalData.withMergeFrom(Object aFrom, String... aFromPathElements) HalData.withMergeFrom(Object aFrom, Collection<?> aFromPathElements) HalData.withMergeFrom(ImmutablePathTable<String> aFrom, Object aFromPath) HalData.withMergeFrom(ImmutablePathTable<String> aFrom, Object... aFromPathElements) HalData.withMergeFrom(ImmutablePathTable<String> aFrom, String aFromPath) HalData.withMergeFrom(ImmutablePathTable<String> aFrom, String... aFromPathElements) HalData.withMergeFrom(ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) HalData.withMergeTo(Object[] aToPathElements, Object aFrom) HalData.withMergeTo(Object[] aToPathElements, ImmutablePathTable<String> aFrom) HalData.withMergeTo(Object aToPath, Object aFrom) HalData.withMergeTo(Object aToPath, ImmutablePathTable<String> aFrom) HalData.withMergeTo(String[] aToPathElements, Object aFrom) HalData.withMergeTo(String[] aToPathElements, ImmutablePathTable<String> aFrom) HalData.withMergeTo(String aToPath, Object aFrom) HalData.withMergeTo(String aToPath, ImmutablePathTable<String> aFrom) HalData.withMergeTo(Collection<?> aToPathElements, Object aFrom) HalData.withMergeTo(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom) HalData.withPut(Collection<?> aPathElements, String aValue) HalData.withPutBoolean(Object[] aPathElements, Boolean aValue) HalData.withPutBoolean(Object aKey, Boolean aValue) HalData.withPutBoolean(String[] aPathElements, Boolean aValue) HalData.withPutBoolean(String aKey, Boolean aValue) HalData.withPutBoolean(Collection<?> aPathElements, Boolean aValue) HalData.withPutByte(Object[] aPathElements, Byte aValue) HalData.withPutByte(Object aKey, Byte aValue) HalData.withPutByte(String[] aPathElements, Byte aValue) HalData.withPutByte(String aKey, Byte aValue) HalData.withPutByte(Collection<?> aPathElements, Byte aValue) HalData.withPutChar(Object[] aPathElements, Character aValue) HalData.withPutChar(Object aKey, Character aValue) HalData.withPutChar(String[] aPathElements, Character aValue) HalData.withPutChar(String aKey, Character aValue) HalData.withPutChar(Collection<?> aPathElements, Character aValue) <C> HalDataHalData.withPutClass(Object[] aPathElements, Class<C> aValue) <C> HalDataHalData.withPutClass(Object aKey, Class<C> aValue) <C> HalDataHalData.withPutClass(String[] aPathElements, Class<C> aValue) <C> HalDataHalData.withPutClass(String aKey, Class<C> aValue) <C> HalDataHalData.withPutClass(Collection<?> aPathElements, Class<C> aValue) HalData.withPutDirAt(int aIndex, Object aDir) HalData.withPutDirAt(int aIndex, ImmutablePathTable<String> aDir) HalData.withPutDirAt(Object[] aPathElements, int aIndex, Object aDir) HalData.withPutDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) HalData.withPutDirAt(Object aPath, int aIndex, Object aDir) HalData.withPutDirAt(Object aPath, int aIndex, ImmutablePathTable<String> aDir) HalData.withPutDirAt(String[] aPathElements, int aIndex, Object aDir) HalData.withPutDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) HalData.withPutDirAt(String aPath, int aIndex, Object aDir) HalData.withPutDirAt(String aPath, int aIndex, ImmutablePathTable<String> aDir) HalData.withPutDirAt(Collection<?> aPathElements, int aIndex, Object aDir) HalData.withPutDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<String> aDir) HalData.withPutDouble(Object[] aPathElements, Double aValue) HalData.withPutDouble(Object aKey, Double aValue) HalData.withPutDouble(String[] aPathElements, Double aValue) HalData.withPutDouble(String aKey, Double aValue) HalData.withPutDouble(Collection<?> aPathElements, Double aValue) HalData.withPutEnum(Object[] aPathElements, E aValue) HalData.withPutEnum(Object aKey, E aValue) HalData.withPutEnum(String[] aPathElements, E aValue) HalData.withPutEnum(String aKey, E aValue) HalData.withPutEnum(Collection<?> aPathElements, E aValue) HalData.withPutFloat(Object[] aPathElements, Float aValue) HalData.withPutFloat(Object aKey, Float aValue) HalData.withPutFloat(String[] aPathElements, Float aValue) HalData.withPutFloat(String aKey, Float aValue) HalData.withPutFloat(Collection<?> aPathElements, Float aValue) HalData.withPutInt(Object[] aPathElements, Integer aValue) HalData.withPutInt(Object aKey, Integer aValue) HalData.withPutInt(String[] aPathElements, Integer aValue) HalData.withPutInt(String aKey, Integer aValue) HalData.withPutInt(Collection<?> aPathElements, Integer aValue) HalData.withPutLong(Object[] aPathElements, Long aValue) HalData.withPutLong(Object aKey, Long aValue) HalData.withPutLong(String[] aPathElements, Long aValue) HalData.withPutLong(String aKey, Long aValue) HalData.withPutLong(Collection<?> aPathElements, Long aValue) HalData.withPutShort(Object[] aPathElements, Short aValue) HalData.withPutShort(Object aKey, Short aValue) HalData.withPutShort(String[] aPathElements, Short aValue) HalData.withPutShort(String aKey, Short aValue) HalData.withPutShort(Collection<?> aPathElements, Short aValue) HalData.withPutString(Object[] aPathElements, String aValue) HalData.withPutString(Object aKey, String aValue) HalData.withPutString(String[] aPathElements, String aValue) HalData.withPutString(String aKey, String aValue) HalData.withPutString(Collection<?> aPathElements, String aValue) HalData.withRemoveFrom(Object aPath) HalData.withRemoveFrom(Object... aPathElements) HalData.withRemoveFrom(String aPath) HalData.withRemoveFrom(String... aPathElements) HalData.withRemoveFrom(Collection<?> aPathElements) HalData.withRemovePaths(String... aPathElements) Methods in org.refcodes.hal with parameters of type HalDataModifier and TypeMethodDescriptionCreates a new entitie's element (row) at the HAL resource consisting of the properties as of the providedImmutableCanonicalTable.Updates an existing entitie's element (row) at the HAL resource using the properties as of the providedImmutableCanonicalTable.