Uses of Class
org.refcodes.hal.HalDataPage

  • Uses of HalDataPage in org.refcodes.hal

    Methods in org.refcodes.hal that return HalDataPage
    Modifier and Type
    Method
    Description
    HalClient.readAll(String aEntity)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.
    HalClient.readAll(String aEntity, TraversalMode aMode)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.
    HalClient.readAll(String aEntity, TraversalMode aMode, FormFields aQueryFields)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.
    HalClient.readAll(String aEntity, FormFields aQueryFields)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.
    HalClient.readPage(String aEntity, int aPage, int aPageSize)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.
    HalClient.readPage(String aEntity, int aPage, int aPageSize, TraversalMode aMode)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.
    HalClient.readPage(String aEntity, int aPage, int aPageSize, TraversalMode aMode, FormFields aQueryFields)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.
    HalClient.readPage(String aEntity, int aPage, int aPageSize, FormFields aQueryFields)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.