In case the a paginated result set is expected when querying the
HalClient, then a HalDataPage will be returned containing the
the HalData instances correlating to the requested page as well as
additional information about the number of total pages available.
The HalStruct interface defines a CanonicalTable
https://www.metacodes.proized for representing the structure including
Meta-Data of a HalStruct instance .