All Classes and Interfaces
Class
Description
The
HalClient lets you comfortably introspect and manage (in terms of
CRUD) HAL resources./** The
HalData interface defines a CanonicalMap.CanonicalMapBuilder
https://www.metacodes.proized for working with HAL-Browser data.In case the a paginated result set is expected when querying the
HalClient, then a HalDataPage will be returned containing the
the HalData instances correlating to the requested page as well as
additional information about the number of total pages available.The base exception for HAL related issues.
Common type for HAL related data.
The base runtime exception for HAL related issues.
The
TraversalMode specifies on how data in retrieved from a
HAL-Resource.