Class HalDataPage

java.lang.Object
All Implemented Interfaces:
Serializable, Cloneable, Iterable<HalData>, Collection<HalData>, List<HalData>, RandomAccess, SequencedCollection<HalData>

public class HalDataPage extends ArrayList<HalData>
In case the a paginated result set is expected when querying the HalClient, then a HalDataPage will be returned containing the the HalData instances correlating to the requested page as well as additional information about the number of total pages available. Paginated result sets may be expected when calling methods such as HalClient.readPage(String, int, int) or HalClient.readAll(String, org.refcodes.web.FormFields) (or similar) with HTTP-Query-Fields querying a paginated result.
See Also: