- All Known Implementing Classes:
HalDataPageImpl
In case the a paginated result set is expected when querying the
HalClient, then a HalDataPage will be returned containing the
the HalData instances correlating to the requested page as well as
additional information about the number of total pages available. Pagainated
result sets may be expected when calling methods such as
HalClient.readPage(String, int, int) or
HalClient.readAll(String, org.refcodes.web.FormFields) (or similar)
with HTTP-Query-Fields querying a paginated result.-
Field Summary
Fields -
Method Summary
Modifier and TypeMethodDescriptionintReturns the total number of the pages which are available for retrieval.intReturns the number of the page which thisHalDataPageinstances represents.intReturns the maximum size of the page being requested for theHalDataPageresult set.Methods inherited from interface java.util.Collection
parallelStream, removeIf, stream, toArrayMethods inherited from interface java.util.List
add, add, addAll, addAll, clear, contains, containsAll, equals, get, hashCode, indexOf, isEmpty, iterator, lastIndexOf, listIterator, listIterator, remove, remove, removeAll, replaceAll, retainAll, set, size, sort, spliterator, subList, toArray, toArray
-
Field Details
-
PAGE_NUMBER
The path to the page's number value (e.g. in anHttpBodyMap).- See Also:
-
PAGE_SIZE
The path to the page's size value (e.g. in anHttpBodyMap).- See Also:
-
PAGE_COUNT
The path to the total page count value (e.g. in anHttpBodyMap).- See Also:
-
-
Method Details
-
getPageNumber
int getPageNumber()Returns the number of the page which thisHalDataPageinstances represents.- Returns:
- The
HalDataPageresult set's page number as of pagination.
-
getPageSize
int getPageSize()Returns the maximum size of the page being requested for theHalDataPageresult set. Returns -1 in case no page size has been specified.- Returns:
- The
HalDataPageresult set's page size as of pagination.
-
getPageCount
int getPageCount()Returns the total number of the pages which are available for retrieval.- Returns:
- The total number of the pages repesenting the overall result set..
-