Interface HalDataPage

    • Field Detail

      • PAGE_NUMBER

        static final String PAGE_NUMBER
        The path to the page's number value (e.g. in an HttpBodyMap).
        See Also:
        Constant Field Values
      • PAGE_COUNT

        static final String PAGE_COUNT
        The path to the total page count value (e.g. in an HttpBodyMap).
        See Also:
        Constant Field Values
    • Method Detail

      • getPageNumber

        int getPageNumber()
        Returns the number of the page which this HalDataPage instances represents.
        Returns:
        The HalDataPage result set's page number as of pagination.
      • getPageSize

        int getPageSize()
        Returns the maximum size of the page being requested for the HalDataPage result set. Returns -1 in case no page size has been specified.
        Returns:
        The HalDataPage result set's page size as of pagination.
      • getPageCount

        int getPageCount()
        Returns the total number of the pages which are available for retrieval.
        Returns:
        The total number of the pages repesenting the overall result set..