-
- All Known Implementing Classes:
HalDataPageImpl
public interface HalDataPage extends List<HalData>
In case the a paginated result set is expected when querying theHalClient, then aHalDataPagewill be returned containing the theHalDatainstances correlating to the requested page as well as additional information about the number of total pages available. Pagainated result sets may be expected when calling methods such asHalClient.readPage(String, int, int)orHalClient.readAll(String, org.refcodes.web.FormFields)(or similar) with HTTP-Query-Fields querying a paginated result.
-
-
Field Summary
Fields Modifier and Type Field Description static StringPAGE_COUNTThe path to the total page count value (e.g. in anHttpBodyMap).static StringPAGE_NUMBERThe path to the page's number value (e.g. in anHttpBodyMap).static StringPAGE_SIZEThe path to the page's size value (e.g. in anHttpBodyMap).
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description intgetPageCount()Returns the total number of the pages which are available for retrieval.intgetPageNumber()Returns the number of the page which thisHalDataPageinstances represents.intgetPageSize()Returns the maximum size of the page being requested for theHalDataPageresult set.-
Methods inherited from interface java.util.Collection
parallelStream, removeIf, stream, toArray
-
Methods inherited from interface java.util.List
add, add, addAll, addAll, clear, contains, containsAll, equals, get, hashCode, indexOf, isEmpty, iterator, lastIndexOf, listIterator, listIterator, remove, remove, removeAll, replaceAll, retainAll, set, size, sort, spliterator, subList, toArray, toArray
-
-
-
-
Field Detail
-
PAGE_NUMBER
static final String PAGE_NUMBER
The path to the page's number value (e.g. in anHttpBodyMap).- See Also:
- Constant Field Values
-
PAGE_SIZE
static final String PAGE_SIZE
The path to the page's size value (e.g. in anHttpBodyMap).- See Also:
- Constant Field Values
-
PAGE_COUNT
static final String PAGE_COUNT
The path to the total page count value (e.g. in anHttpBodyMap).- See Also:
- Constant Field Values
-
-
Method Detail
-
getPageNumber
int getPageNumber()
Returns the number of the page which thisHalDataPageinstances represents.- Returns:
- The
HalDataPageresult set's page number as of pagination.
-
getPageSize
int getPageSize()
Returns the maximum size of the page being requested for theHalDataPageresult set. Returns -1 in case no page size has been specified.- Returns:
- The
HalDataPageresult set's page size as of pagination.
-
getPageCount
int getPageCount()
Returns the total number of the pages which are available for retrieval.- Returns:
- The total number of the pages repesenting the overall result set..
-
-