Uses of Class
org.refcodes.hal.HalClient
-
Uses of HalClient in org.refcodes.hal
Methods in org.refcodes.hal that return HalClientModifier and TypeMethodDescriptionHalClient.withExcludeEntities(String[] entities) Sets the names of the entities to be excluded by theHalClient.HalClient.withIncludeEntities(String[] entities) Sets the names of the entities to be included by theHalClient.HalClient.withOAuthToken(org.refcodes.web.OauthToken aOauthToken)