Uses of Interface
org.refcodes.hal.HalClient
-
-
Uses of HalClient in org.refcodes.hal
Classes in org.refcodes.hal that implement HalClient Modifier and Type Class Description classHalClientImplMethods in org.refcodes.hal that return HalClient Modifier and Type Method Description default HalClientHalClient. withExcludeEntities(String[] entities)Sets the names of the entities to be excluded by theHalClient.default HalClientHalClient. withIncludeEntities(String[] entities)Sets the names of the entities to be included by theHalClient.default HalClientHalClient. withOAuthToken(org.refcodes.web.OauthToken aOauthToken)
-