Uses of Class
org.refcodes.hal.HalData
-
Uses of HalData in org.refcodes.hal
Methods in org.refcodes.hal that return HalDataModifier and TypeMethodDescriptionCreates a new entitie's element (row) at the HAL resource consisting of the properties as of the providedCanonicalMap.Creates a new entitie's element (row) at the HAL resource consisting of the properties as of the providedCanonicalMap.HalData.exportHref(Object aPath) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(Object... aPathElements) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(Object[] aPathElements, org.refcodes.web.FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(Object aPath, org.refcodes.web.FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(String aPath) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(String... aPathElements) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(String[] aPathElements, org.refcodes.web.FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(String aPath, org.refcodes.web.FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(Collection<?> aPathElements) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(Collection<?> aPathElements, org.refcodes.web.FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, Object aPath) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, Object... aPathElements) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, Object[] aPathElements, org.refcodes.web.FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, Object aPath, org.refcodes.web.FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, String aPath) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, String... aPathElements) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, String[] aPathElements, org.refcodes.web.FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, String aPath, org.refcodes.web.FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, Collection<?> aPathElements) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.exportHref(TraversalMode aMode, Collection<?> aPathElements, org.refcodes.web.FormFields aQueryFields) Exports the data of the HAL-Resource to which value points referenced by the path.HalData.getDirAt(int aIndex) HalData.putDirAt(Collection<?> aPathElements, int aIndex, Object aDir) HalData.putDirAt(Collection<?> aPathElements, int aIndex, org.refcodes.struct.PathMap<String> aDir) HalData.query(Collection<?> aQueryElements) HalData.queryBetween(Object[] aFromPath, Object[] aPathQuery, Object[] aToPath) HalData.queryBetween(Object aFromPath, Object aPathQuery, Object aToPath) HalData.queryBetween(String[] aFromPath, String[] aPathQuery, String[] aToPath) HalData.queryBetween(String aFromPath, String aPathQuery, String aToPath) HalData.queryBetween(String aFromPath, Pattern aRegExp, String aToPath) HalData.queryBetween(Collection<?> aFromPath, Collection<?> aPathQuery, Collection<?> aToPath) HalData.queryFrom(Collection<?> aPathQuery, Collection<?> aFromPath) HalData.queryTo(Collection<?> aPathQuery, String aToPath) Retrieves the properties with the according values for the given entity with the given TID from the HAL resource.HalClient.read(String aEntity, Long aId, TraversalMode aMode) Retrieves the properties with the according values for the given entity with the given TID from the HAL resource.HalClient.read(String aEntity, Long aId, TraversalMode aMode, org.refcodes.web.FormFields aQueryFields) Retrieves the properties with the according values for the given entity with the given TID from the HAL resource.Retrieves the properties with the according values for the given entity with the given TID from the HAL resource.HalData.removeAll(Collection<?> aPathQueryElements) HalData.removeDirAt(int aIndex) HalData.removeDirAt(Object[] aPathElements, int aIndex) HalData.removeDirAt(Object aPath, int aIndex) HalData.removeDirAt(String[] aPathElements, int aIndex) HalData.removeDirAt(String aPath, int aIndex) HalData.removeFrom(Object aPath) HalData.removeFrom(Object... aPathElements) HalData.removeFrom(String aPath) HalData.removeFrom(String... aPathElements) HalData.removePaths(String... aPaths) HalData.removePaths(Collection<?> aPaths) HalData.retrieveBetween(Object[] aFromPath, Object[] aToPath) HalData.retrieveBetween(Object aFromPath, Object aToPath) HalData.retrieveBetween(String[] aFromPath, String[] aToPath) HalData.retrieveBetween(String aFromPath, String aToPath) HalData.retrieveBetween(Collection<?> aFromPath, Collection<?> aToPath) HalData.retrieveFrom(Object aParentPath) HalData.retrieveFrom(Object... aPathElements) HalData.retrieveFrom(String aFromPath) HalData.retrieveFrom(String... aPathElements) HalData.retrieveFrom(Collection<?> aPathElements) HalData.retrieveTo(Object aToPath) HalData.retrieveTo(Object... aToPathElements) HalData.retrieveTo(String aToPath) HalData.retrieveTo(String... aToPathElements) HalData.retrieveTo(Collection<?> aToPathElements) Creates a new entitie's element (row) at the HAL resource consisting of the properties as of the providedCanonicalMap.Updates an existing entitie's element (row) at the HAL resource using the properties as of the providedCanonicalMap.HalData.withInsert(Object aObj) HalData.withInsert(org.refcodes.struct.PathMap<String> aFrom) HalData.withInsertBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) HalData.withInsertBetween(Object[] aToPathElements, org.refcodes.struct.PathMap<String> aFrom, Object[] aFromPathElements) HalData.withInsertBetween(Object aToPath, Object aFrom, Object aFromPath) HalData.withInsertBetween(Object aToPath, org.refcodes.struct.PathMap<String> aFrom, Object aFromPath) HalData.withInsertBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) HalData.withInsertBetween(String[] aToPathElements, org.refcodes.struct.PathMap<String> aFrom, String[] aFromPathElements) HalData.withInsertBetween(String aToPath, Object aFrom, String aFromPath) HalData.withInsertBetween(String aToPath, org.refcodes.struct.PathMap<String> aFrom, String aFromPath) HalData.withInsertBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) HalData.withInsertBetween(Collection<?> aToPathElements, org.refcodes.struct.PathMap<String> aFrom, Collection<?> aFromPathElements) HalData.withInsertFrom(Object aFrom, Object aFromPath) HalData.withInsertFrom(Object aFrom, Object... aFromPathElements) HalData.withInsertFrom(Object aFrom, String aFromPath) HalData.withInsertFrom(Object aFrom, String... aFromPathElements) HalData.withInsertFrom(Object aFrom, Collection<?> aFromPathElements) HalData.withInsertFrom(org.refcodes.struct.PathMap<String> aFrom, Object aFromPath) HalData.withInsertFrom(org.refcodes.struct.PathMap<String> aFrom, Object... aFromPathElements) HalData.withInsertFrom(org.refcodes.struct.PathMap<String> aFrom, String aFromPath) HalData.withInsertFrom(org.refcodes.struct.PathMap<String> aFrom, String... aFromPathElements) HalData.withInsertFrom(org.refcodes.struct.PathMap<String> aFrom, Collection<?> aFromPathElements) HalData.withInsertTo(Object[] aToPathElements, Object aFrom) HalData.withInsertTo(Object[] aToPathElements, org.refcodes.struct.PathMap<String> aFrom) HalData.withInsertTo(Object aToPath, Object aFrom) HalData.withInsertTo(Object aToPath, org.refcodes.struct.PathMap<String> aFrom) HalData.withInsertTo(String[] aToPathElements, Object aFrom) HalData.withInsertTo(String[] aToPathElements, org.refcodes.struct.PathMap<String> aFrom) HalData.withInsertTo(String aToPath, Object aFrom) HalData.withInsertTo(String aToPath, org.refcodes.struct.PathMap<String> aFrom) HalData.withInsertTo(Collection<?> aToPathElements, Object aFrom) HalData.withInsertTo(Collection<?> aToPathElements, org.refcodes.struct.PathMap<String> aFrom) HalData.withMergeBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) HalData.withMergeBetween(Object[] aToPathElements, org.refcodes.struct.PathMap<String> aFrom, Object[] aFromPathElements) HalData.withMergeBetween(Object aToPath, Object aFrom, Object aFromPath) HalData.withMergeBetween(Object aToPath, org.refcodes.struct.PathMap<String> aFrom, Object aFromPath) HalData.withMergeBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) HalData.withMergeBetween(String[] aToPathElements, org.refcodes.struct.PathMap<String> aFrom, String[] aFromPathElements) HalData.withMergeBetween(String aToPath, Object aFrom, String aFromPath) HalData.withMergeBetween(String aToPath, org.refcodes.struct.PathMap<String> aFrom, String aFromPath) HalData.withMergeBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) HalData.withMergeBetween(Collection<?> aToPathElements, org.refcodes.struct.PathMap<String> aFrom, Collection<?> aFromPathElements) HalData.withMergeFrom(Object aFrom, Object aFromPath) HalData.withMergeFrom(Object aFrom, Object... aFromPathElements) HalData.withMergeFrom(Object aFrom, String aFromPath) HalData.withMergeFrom(Object aFrom, String... aFromPathElements) HalData.withMergeFrom(Object aFrom, Collection<?> aFromPathElements) HalData.withMergeFrom(org.refcodes.struct.PathMap<String> aFrom, Object aFromPath) HalData.withMergeFrom(org.refcodes.struct.PathMap<String> aFrom, Object... aFromPathElements) HalData.withMergeFrom(org.refcodes.struct.PathMap<String> aFrom, String aFromPath) HalData.withMergeFrom(org.refcodes.struct.PathMap<String> aFrom, String... aFromPathElements) HalData.withMergeFrom(org.refcodes.struct.PathMap<String> aFrom, Collection<?> aFromPathElements) HalData.withMergeTo(Object[] aToPathElements, Object aFrom) HalData.withMergeTo(Object[] aToPathElements, org.refcodes.struct.PathMap<String> aFrom) HalData.withMergeTo(Object aToPath, Object aFrom) HalData.withMergeTo(Object aToPath, org.refcodes.struct.PathMap<String> aFrom) HalData.withMergeTo(String[] aToPathElements, Object aFrom) HalData.withMergeTo(String[] aToPathElements, org.refcodes.struct.PathMap<String> aFrom) HalData.withMergeTo(String aToPath, Object aFrom) HalData.withMergeTo(String aToPath, org.refcodes.struct.PathMap<String> aFrom) HalData.withMergeTo(Collection<?> aToPathElements, Object aFrom) HalData.withMergeTo(Collection<?> aToPathElements, org.refcodes.struct.PathMap<String> aFrom) HalData.withPut(Collection<?> aPathElements, String aValue) HalData.withPut(org.refcodes.struct.Property aProperty) HalData.withPutBoolean(Object[] aPathElements, Boolean aValue) HalData.withPutBoolean(Object aKey, Boolean aValue) HalData.withPutBoolean(String[] aPathElements, Boolean aValue) HalData.withPutBoolean(String aKey, Boolean aValue) HalData.withPutBoolean(Collection<?> aPathElements, Boolean aValue) HalData.withPutByte(Object[] aPathElements, Byte aValue) HalData.withPutByte(Object aKey, Byte aValue) HalData.withPutByte(String[] aPathElements, Byte aValue) HalData.withPutByte(String aKey, Byte aValue) HalData.withPutByte(Collection<?> aPathElements, Byte aValue) HalData.withPutChar(Object[] aPathElements, Character aValue) HalData.withPutChar(Object aKey, Character aValue) HalData.withPutChar(String[] aPathElements, Character aValue) HalData.withPutChar(String aKey, Character aValue) HalData.withPutChar(Collection<?> aPathElements, Character aValue) <C> HalDataHalData.withPutClass(Object[] aPathElements, Class<C> aValue) <C> HalDataHalData.withPutClass(Object aKey, Class<C> aValue) <C> HalDataHalData.withPutClass(String[] aPathElements, Class<C> aValue) <C> HalDataHalData.withPutClass(String aKey, Class<C> aValue) <C> HalDataHalData.withPutClass(Collection<?> aPathElements, Class<C> aValue) HalData.withPutDirAt(int aIndex, Object aDir) HalData.withPutDirAt(int aIndex, org.refcodes.struct.PathMap<String> aDir) HalData.withPutDirAt(Object[] aPathElements, int aIndex, Object aDir) HalData.withPutDirAt(Object[] aPathElements, int aIndex, org.refcodes.struct.PathMap<String> aDir) HalData.withPutDirAt(Object aPath, int aIndex, Object aDir) HalData.withPutDirAt(Object aPath, int aIndex, org.refcodes.struct.PathMap<String> aDir) HalData.withPutDirAt(String[] aPathElements, int aIndex, Object aDir) HalData.withPutDirAt(String[] aPathElements, int aIndex, org.refcodes.struct.PathMap<String> aDir) HalData.withPutDirAt(String aPath, int aIndex, Object aDir) HalData.withPutDirAt(String aPath, int aIndex, org.refcodes.struct.PathMap<String> aDir) HalData.withPutDirAt(Collection<?> aPathElements, int aIndex, Object aDir) HalData.withPutDirAt(Collection<?> aPathElements, int aIndex, org.refcodes.struct.PathMap<String> aDir) HalData.withPutDouble(Object[] aPathElements, Double aValue) HalData.withPutDouble(Object aKey, Double aValue) HalData.withPutDouble(String[] aPathElements, Double aValue) HalData.withPutDouble(String aKey, Double aValue) HalData.withPutDouble(Collection<?> aPathElements, Double aValue) HalData.withPutEnum(Object[] aPathElements, E aValue) HalData.withPutEnum(Object aKey, E aValue) HalData.withPutEnum(String[] aPathElements, E aValue) HalData.withPutEnum(String aKey, E aValue) HalData.withPutEnum(Collection<?> aPathElements, E aValue) HalData.withPutFloat(Object[] aPathElements, Float aValue) HalData.withPutFloat(Object aKey, Float aValue) HalData.withPutFloat(String[] aPathElements, Float aValue) HalData.withPutFloat(String aKey, Float aValue) HalData.withPutFloat(Collection<?> aPathElements, Float aValue) HalData.withPutInt(Object[] aPathElements, Integer aValue) HalData.withPutInt(Object aKey, Integer aValue) HalData.withPutInt(String[] aPathElements, Integer aValue) HalData.withPutInt(String aKey, Integer aValue) HalData.withPutInt(Collection<?> aPathElements, Integer aValue) HalData.withPutLong(Object[] aPathElements, Long aValue) HalData.withPutLong(Object aKey, Long aValue) HalData.withPutLong(String[] aPathElements, Long aValue) HalData.withPutLong(String aKey, Long aValue) HalData.withPutLong(Collection<?> aPathElements, Long aValue) HalData.withPutShort(Object[] aPathElements, Short aValue) HalData.withPutShort(Object aKey, Short aValue) HalData.withPutShort(String[] aPathElements, Short aValue) HalData.withPutShort(String aKey, Short aValue) HalData.withPutShort(Collection<?> aPathElements, Short aValue) HalData.withPutString(Object[] aPathElements, String aValue) HalData.withPutString(Object aKey, String aValue) HalData.withPutString(String[] aPathElements, String aValue) HalData.withPutString(String aKey, String aValue) HalData.withPutString(Collection<?> aPathElements, String aValue) HalData.withRemoveFrom(Object aPath) HalData.withRemoveFrom(Object... aPathElements) HalData.withRemoveFrom(String aPath) HalData.withRemoveFrom(String... aPathElements) HalData.withRemoveFrom(Collection<?> aPathElements) HalData.withRemovePaths(String... aPathElements) Methods in org.refcodes.hal with parameters of type HalDataModifier and TypeMethodDescriptionCreates a new entitie's element (row) at the HAL resource consisting of the properties as of the providedCanonicalMap.Updates an existing entitie's element (row) at the HAL resource using the properties as of the providedCanonicalMap.