Uses of Interface
org.refcodes.hal.HalDataPage

  • Uses of HalDataPage in org.refcodes.hal

    Classes in org.refcodes.hal that implement HalDataPage
    Modifier and Type Class Description
    class  HalDataPageImpl
    Implementation of the HalDataPage interface.
    Methods in org.refcodes.hal that return HalDataPage
    Modifier and Type Method Description
    default HalDataPage HalClient.readAll​(String aEntity)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.
    default HalDataPage HalClient.readAll​(String aEntity, TraversalMode aMode)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.
    HalDataPage HalClient.readAll​(String aEntity, TraversalMode aMode, org.refcodes.web.FormFields aQueryFields)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.
    default HalDataPage HalClient.readAll​(String aEntity, org.refcodes.web.FormFields aQueryFields)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.
    HalDataPage HalClientImpl.readAll​(String aEntity, TraversalMode aMode, org.refcodes.web.FormFields aQueryFields)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.
    default HalDataPage HalClient.readPage​(String aEntity, int aPage, int aPageSize)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.
    default HalDataPage HalClient.readPage​(String aEntity, int aPage, int aPageSize, TraversalMode aMode)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.
    default HalDataPage HalClient.readPage​(String aEntity, int aPage, int aPageSize, TraversalMode aMode, org.refcodes.web.FormFields aQueryFields)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.
    default HalDataPage HalClient.readPage​(String aEntity, int aPage, int aPageSize, org.refcodes.web.FormFields aQueryFields)
    Retrieves the properties with the according values of all elements (rows) for the given entity from the HAL resource.