Module org.refcodes.hal
Package org.refcodes.hal
package org.refcodes.hal
-
ClassDescriptionThe
HalClientlets you comfortably introspect and manage (in terms of CRUD) HAL resources./** TheHalDatainterface defines aCanonicalMap.CanonicalMapBuilderhttps://www.metacodes.proized for working with HAL-Browser data.In case the a paginated result set is expected when querying theHalClient, then aHalDataPagewill be returned containing the theHalDatainstances correlating to the requested page as well as additional information about the number of total pages available.The base exception for HAL related issues.Common type for HAL related data.The base runtime exception for HAL related issues.TheTraversalModespecifies on how data in retrieved from a HAL-Resource.