Module org.refcodes.hal
Package org.refcodes.hal
-
Interface Summary Interface Description HalClient TheHalClientlets you comfortably introspect and manage (in terms of CRUD) HAL resources.HalData TheHalDatainterface defines aCanonicalMap.CanonicalMapBuilderspecialized for working with HAL-Browser data.HalDataPage In case the a paginated result set is expected when querying theHalClient, then aHalDataPagewill be returned containing the theHalDatainstances correlating to the requested page as well as additional information about the number of total pages available.HalMap Common interface for HAL-Data related operation,HalStruct -
Class Summary Class Description HalClientImpl HalDataImpl HalDataPageImpl Implementation of theHalDataPageinterface.HalMapImpl HalStructImpl TheHalStructImplimplements theHalStructinterface by extending theCanonicalMapBuilderImplclass. -
Enum Summary Enum Description TraversalMode TheTraversalModespecifies on how data in retrieved from a HAL-Resource. -
Exception Summary Exception Description HalException The base exception for HAL related issues.HalRuntimeException The base runtime exception for HAL related issues.