Uses of Package
org.refcodes.hal

  • Class
    Description
    The HalClient lets you comfortably introspect and manage (in terms of CRUD) HAL resources.
    The HalData interface defines a CanonicalMap.CanonicalMapBuilder specialized for working with HAL-Browser data.
    In case the a paginated result set is expected when querying the HalClient, then a HalDataPage will be returned containing the the HalData instances correlating to the requested page as well as additional information about the number of total pages available.
    Common interface for HAL-Data related operation,
    The HalStruct interface defines a CanonicalMap.CanonicalMapBuilder specialized for representing the structure including Meta-Data of a HalStruct instance .
    The TraversalMode specifies on how data in retrieved from a HAL-Resource.