Uses of Package
org.refcodes.hal
-
Classes in org.refcodes.hal used by org.refcodes.hal Class Description HalClient TheHalClientlets you comfortably introspect and manage (in terms of CRUD) HAL resources.HalData TheHalDatainterface defines aCanonicalMap.CanonicalMapBuilderspecialized for working with HAL-Browser data.HalDataPage In case the a paginated result set is expected when querying theHalClient, then aHalDataPagewill be returned containing the theHalDatainstances correlating to the requested page as well as additional information about the number of total pages available.HalMap Common interface for HAL-Data related operation,HalStruct TraversalMode TheTraversalModespecifies on how data in retrieved from a HAL-Resource.